import { TransactionEntity } from 'src/modules/transaction/transaction/domain/entities/transaction.entity';

export function mappingHeader() {
  return [
    {
      stack: [
        {
          alignment: 'center',
          columns: [
            {
              width: 100,
              image: 'data',
            },
            {
              width: 'auto',
              text: 'have',
              fontSize: 50,
              bold: true,
              color: '#169f54',
              padding: [0, 0, 0, 0],
              margin: [0, 0, 0, 0],
              alignment: 'center',
            },
            {
              width: 'auto',
              text: 'fun',
              fontSize: 50,
              bold: true,
              color: '#61c4eb',
              padding: [0, 0, 0, 0],
              margin: [0, 0, 0, 0],
              // alignment: "center"
            },
          ],
        },
        {
          text: 'BOOKING DATE CHANGE',
          fontSize: 30,
          alignment: 'center',
        },
        {
          columns: [
            {
              text: 'INV-20808/032',
            },
            {
              text: '10 Juli 2024',
              alignment: 'right',
            },
          ],
        },
      ],
    },
    {
      width: 150,
      text: 'Jl, Kolonel Masturi No.KM. 11, \n Kertawangi, Kec. Cisatua, \n Kab. Bandung Barat, \n Jawa Barat 40551 \n 0815-6380-8021',
      //   color: '#aaaaab',
      //   bold: true,
      fontSize: 11,
      margin: [0, 20, 0, 5],
    },
  ];
}

export function mappingFooter() {
  return [
    [
      {
        text: 'we commits to prividing an educative, \n playful, and purposeful environment\n this is advantageous for all ages',
        border: [false, true, false, false],
        margin: [0, 5, 0, 5],
        alignment: 'right',
      },
      {
        text: 'Thank \n You',
        border: [false, true, false, false],
        fontSize: 20,
        bold: true,
        color: '#169f54',
        margin: [0, 5, 0, 5],
      },
    ],
  ];
}

export function mappingPrice(transaction: TransactionEntity) {
  const result = [];
  const sub_total = [
    {
      text: 'SUBTOTAL',
      alignment: 'right',
      bold: true,
      margin: [0, 5, 0, 5],
    },
    {
      text: Number(transaction.payment_sub_total).toLocaleString('id-ID', {
        style: 'currency',
        currency: 'IDR',
      }),
      margin: [0, 5, 0, 5],
    },
  ];
  result.push(sub_total);

  if (Number(transaction.payment_discount_total ?? 0) > 0) {
    const discount = [
      {
        text: 'DISCOUNT',
        bold: true,
        alignment: 'right',
        margin: [0, 5, 0, 5],
      },
      {
        text: Number(transaction.payment_discount_total).toLocaleString(
          'id-ID',
          {
            style: 'currency',
            currency: 'IDR',
          },
        ),
        margin: [0, 5, 0, 5],
      },
    ];
    result.push(discount);
  }

  const total = [
    {
      text: 'TOTAL',
      bold: true,
      border: [false, false, false, true],
      alignment: 'right',
      margin: [0, 5, 0, 5],
    },
    {
      text: Number(transaction.payment_total).toLocaleString('id-ID', {
        style: 'currency',
        currency: 'IDR',
      }),
      border: [false, false, false, true],
      margin: [0, 5, 0, 5],
    },
  ];
  result.push(total);

  return result;
}

export function mappingItem(items) {
  const header = [
    {
      text: 'ITEM',
      border: [false, true, false, false],
      margin: [0, 5, 0, 5],
      bold: true,
      textTransform: 'uppercase',
    },
    {
      text: 'QTY',
      alignment: 'center',
      border: [false, true, false, false],
      margin: [0, 5, 0, 5],
      bold: true,
      textTransform: 'uppercase',
    },
    {
      text: 'PRICE',
      alignment: 'center',
      border: [false, true, false, false],
      margin: [0, 5, 0, 5],
      bold: true,
      textTransform: 'uppercase',
    },
    {
      text: 'AMOUNT',
      border: [false, true, false, false],
      alignment: 'center',
      bold: true,
      margin: [0, 5, 0, 5],
      textTransform: 'uppercase',
    },
  ];

  const result = [];
  items.forEach((item) => {
    const dataRow = [
      {
        text: item.item_name,
        margin: [0, 5, 0, 5],
        alignment: 'left',
      },
      {
        text: item.qty,
        margin: [0, 5, 0, 5],
        alignment: 'center',
      },
      {
        text: Number(item.item_price).toLocaleString('id-ID', {
          style: 'currency',
          currency: 'IDR',
        }),
        margin: [0, 5, 0, 5],
        alignment: 'right',
      },
      {
        text: Number(item.total_price).toLocaleString('id-ID', {
          style: 'currency',
          currency: 'IDR',
        }),
        alignment: 'right',
        margin: [0, 5, 0, 5],
      },
    ];
    result.push(dataRow);
  });

  const body = [header, ...result];

  return body;
}

export function mappingBody() {
  // booking date change information
  return [
    "Great news! We've successfully updated your booking date as per your request. \n We're exited to accommodate your new plans and ensure everything goes smoothly \n\n",
    'Here are your updated booking details:',
    {
      text: '\n\n Original Booking Date: 20 Agustus 2024 \n New Booking Date: 20 Agustus 2025 \n\n',
      bold: true,
    },
    "Here's a quick recap of your order :",
  ];
}

export function mappingBodyBottom() {
  // booking date change information
  return [
    "For your convenience, we've attached a new confirmation receipt reflecting these changes \n",
    'Please be sure to bring this updated receipt with you on the new date \n\n',
    'If you have any questions or need further assistance, our friendly support team is just a call away at \n\n',
    "Thank you and we can't wait to see you and make sure you hove an amazing time!",
  ];
}
